@@ -32,7 +32,6 @@ from sphinx.util import (
 from sphinx.util.nodes import set_source_info
 from sphinx.util.osutil import (
     ensuredir,
-    ENOENT,
 )
 
 try:
@@ -232,7 +231,7 @@ def render_plantuml_inline(self, node, fileformat):
                              stderr=subprocess.PIPE,
                              cwd=absincdir)
     except OSError as err:
-        if err.errno != ENOENT:
+        if err.errno != errno.ENOENT:
             raise
         raise PlantUmlError('plantuml command %r cannot be run'
                             % self.builder.config.plantuml)
@@ -323,7 +322,7 @@ class PlantumlBuilder(object):
             p = subprocess.Popen(cmdargs, stderr=subprocess.PIPE,
                                  cwd=self.cache_dir)
         except OSError as err:
-            if err.errno != ENOENT:
+            if err.errno != errno.ENOENT:
                 raise
             raise PlantUmlError('plantuml command %r cannot be run'
                                 % self.builder.config.plantuml)
@@ -351,7 +350,7 @@ class PlantumlBuilder(object):
                                      stderr=subprocess.PIPE,
                                      cwd=absincdir)
             except OSError as err:
-                if err.errno != ENOENT:
+                if err.errno != errno.ENOENT:
                     raise
                 raise PlantUmlError('plantuml command %r cannot be run'
                                     % self.builder.config.plantuml)
@@ -528,7 +527,7 @@ def _convert_eps_to_pdf(self, refname, fname):
             p = subprocess.Popen(['bash'] + args, stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE)
     except OSError as err:
-        if err.errno != ENOENT:
+        if err.errno != errno.ENOENT:
             raise
         raise PlantUmlError('epstopdf command %r cannot be run'
                             % self.builder.config.plantuml_epstopdf)
@@ -582,11 +581,24 @@ def latex_depart_plantuml(self, node):
     pass
 
 
+_KNOWN_CONFLUENCE_FORMATS = [
+    'png',
+    'svg',
+]
+
+
 def confluence_visit_plantuml(self, node):
     _render_batches_on_vist(self)
     fmt = self.builder.config.plantuml_output_format
-    with _prepare_html_render(self, fmt) as (fileformats, _):
-        _, outfname = render_plantuml(self, node, fileformats[0])
+    if fmt == 'none':
+        raise nodes.SkipNode
+
+    if fmt not in _KNOWN_CONFLUENCE_FORMATS:
+        raise PlantUmlError(
+            'plantuml_output_format must be one of %s, but is %r'
+            % (', '.join(map(repr, _KNOWN_CONFLUENCE_FORMATS)), fmt))
+
+    _, outfname = render_plantuml(self, node, fmt)
 
     # put node representing rendered image
     img_node = nodes.image(uri=outfname, alt=node.get('alt', node['uml']))
